@@ -7,10 +7,13 @@ make clean
 
 make dist
 
+. automation/set_release_suffix.sh
+
 # create the src.rpm
 rpmbuild \
     -D "_srcrpmdir $PWD/output" \
     -D "_topmdir $PWD/rpmbuild" \
+    ${release_suffix:+-D "release_suffix ${release_suffix}"} \
     -ts ./*.gz
 
 # install any build requirements
@@ -20,6 +23,7 @@ yum-builddep output/*src.rpm
 rpmbuild \
     -D "_rpmdir $PWD/output" \
     -D "_topmdir $PWD/rpmbuild" \
+    ${release_suffix:+-D "release_suffix ${release_suffix}"} \
     --rebuild output/*.src.rpm
 
 [[ -d exported-artifacts ]] || mkdir -p exported-artifacts
